@@ -3,7 +3,7 @@ from typing import Dict, Iterable, Optional, Tuple, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
-
+import openmc_tally_unit_converter as otuc
 import plotly.graph_objects as go
 from numpy import ndarray
 from numpy.lib.function_base import trim_zeros
@@ -16,23 +16,61 @@ def plot_spectrum_from_tally(
     x_scale: Optional[str] = "linear",
     y_scale: Optional[str] = "linear",
     title: Optional[str] = "",
-    trim_zeros: bool = True,
     legend: bool = True,
     filename: Optional[str] = None,
-    plotting_package="matplotlib",
-    required_units: str = "centimeters / simulated_particle",
+    plotting_package: Optional[str] = "matplotlib",
+    trim_zeros: bool = True,
+    required_units: str = "centimeters / source_particle",
     required_energy_units: str = "eV",
     source_strength: float = None,
     volume: float = None,
 ):
+    """Plots a stepped line graph with optional shaded region for Y error.
+    Intended use for ploting neutron / photon spectra
 
-    import openmc_post_processor as opp
+    Arguments:
+        spectrum: A dictionary of where the key is the spectra title and the
+            dictionary values openmc.Tally objects. The tally objects can be
+            accessed with the regular openmc.StatePoint('statepoint.batches.h5')
+            method. Spectrum tallies should include an
+            openmc.filter.EnergyFilter
+        x_label: the label to use on the x axis,
+        y_label: the label to use on the y axis,
+        x_scale: the scale to use for the x axis. Options are 'linear', 'log'
+        y_scale: the scale to use for the y axis. Options are 'linear', 'log'
+        title: the title applied to the top of the plot
+        legend: controls if a legend should be displayed or not. If set to True
+            a legend with spectra titles will be displayed and if set to False
+            the legend will not be displayed.
+        filename: the filename to save the plot as should end with the correct
+            extention supported by matplotlib (e.g .png) or plotly (e.g .html)
+        plotting_package: the name of the python package to use when producing
+            the plots. Options are 'matplotlib' or 'plotly'
+        trim_zeros: whether any zero values at the end of the x iterable
+            should be removed from the plot. This is useful when using standard
+            energy groups that go beyond the energy of the particles simulated.
+        required_units: The units desired for the Y axis. Defaults to
+            "centimeters / source_particle" but supports units identified in
+            the Python Pint package. If volume normalisation or source strength
+            normalisation are required by the units then these arguments must
+            also be provided.
+        required_energy_units: "eV",
+        source_strength: The strength of the source which is to be used for
+            source normalization. A numeric value is expected but the units are
+            assumed to be in particles per second or particles per pulse.
+        volume: The volume which is to be used for volume normalisation. A
+            numeric value is expected but the units are assumed to be in cm**3
+            (centimeters cubed).
+
+    Returns:
+        the matplotlib.pyplot or plotly.graph_objects object produced
+    """
 
     dictionary_of_values = {}
 
     for key, value in spectrum.items():
 
-        x_y_y_err = opp.process_spectra_tally(
+        x_y_y_err = otuc.process_spectra_tally(
             tally=value,
             required_units=required_units,
             required_energy_units=required_energy_units,
@@ -69,27 +107,37 @@ def plot_spectrum_from_values(
     x_scale: Optional[str] = "linear",
     y_scale: Optional[str] = "linear",
     title: Optional[str] = "",
-    trim_zeros: bool = True,
     legend: bool = True,
     filename: Optional[str] = None,
-    plotting_package="matplotlib",
-) -> plt:
+    plotting_package: Optional[str] = "matplotlib",
+    trim_zeros: bool = True,
+):
     """Plots a stepped line graph with optional shaded region for Y error.
     Intended use for ploting neutron / photon spectra
 
     Arguments:
-        spectrum: A dictionary of x, y, y_error values
+        spectrum: A dictionary of where the key is the spectra title and the
+            dictionary values are a list containing x and y values. Optionally
+            y_error values can also be included in the list. x, y and y_error
+            should all be numpy arrays.
         x_label: the label to use on the x axis,
         y_label: the label to use on the y axis,
         x_scale: the scale to use for the x axis. Options are 'linear', 'log'
         y_scale: the scale to use for the y axis. Options are 'linear', 'log'
-        title: the plot title
-        filename: the filename to save the plot as
+        title: the title applied to the top of the plot
+        legend: controls if a legend should be displayed or not. If set to True
+            a legend with spectra titles will be displayed and if set to False
+            the legend will not be displayed.
+        filename: the filename to save the plot as should end with the correct
+            extention supported by matplotlib (e.g .png) or plotly (e.g .html)
+        plotting_package: the name of the python package to use when producing
+            the plots. Options are 'matplotlib' or 'plotly'
         trim_zeros: whether any zero values at the end of the x iterable
-            should be removed from the plot.
+            should be removed from the plot. This is useful when using standard
+            energy groups that go beyond the energy of the particles simulated.
 
     Returns:
-        the matplotlib.pyplot object produced
+        the matplotlib.pyplot or plotly.graph_objects object produced
     """
 
     figure = add_axis_title_labels(
@@ -118,7 +166,7 @@ def plot_spectrum_from_values(
 
 
 def save_plot(plotting_package: str, filename: str, figure):
-
+    """Saves the matplotlib or plotly graph object as a file."""
     if filename:
         if plotting_package == "matplotlib":
             figure.savefig(filename, bbox_inches="tight", dpi=400)
@@ -138,9 +186,15 @@ def add_axis_title_labels(
     legend: bool,
     plotting_package: str,
 ):
+    """Adds axis labels and the title to the matplot lib or plotlg graph object"""
 
     if plotting_package == "matplotlib":
-        plt.figure(0)
+
+        plt.close()
+        plt.cla()
+        plt.clf()
+        plt.figure(1, clear=True)
+
         plt.xlabel(x_label)
         plt.ylabel(y_label)
 
@@ -218,6 +272,7 @@ def add_spectra_to_plot(
     plotting_package: str,
     figure,
 ):
+    """Adds a step line to the matplotlib or plotly graph object"""
     # mid and post are also options but pre is used as energy bins start from 0
 
     x = spectra[0]
@@ -242,19 +297,19 @@ def add_spectra_to_plot(
 
     if plotting_package == "matplotlib":
 
-        plt.step(x, y, where="pre", label=label)
+        figure.step(x, y, where="pre", label=label)
 
         if len(spectra) == 3:
             lower_y = y - y_err
             upper_y = y + y_err
-            plt.fill_between(x, lower_y, upper_y, step="pre", color="k", alpha=0.15)
+            figure.fill_between(x, lower_y, upper_y, step="pre", color="k", alpha=0.15)
 
-        return plt
+        return figure
 
     elif plotting_package == "plotly":
 
         # options are 'linear', 'spline', 'hv', 'vh', 'hvh', 'vhv'
-        shape = "vh"
+        shape = "hv"
 
         # adds a line for the upper stanadard deviation bound
         figure.add_trace(
